EmbedController class

Constructors

EmbedController(InAppWebViewController controller)
const

Properties

controller → InAppWebViewController
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

callBackWhenVideoEnd({required dynamic onVideoEnd()?}) → void
callBackWhenVideoSeek({required dynamic onVideoSeek(double currentTime)?}) → void
callBackWhenVideoStateChange({required dynamic onVideoStateChange(VideoState state)?}) → void
callBackWhenVideoTimeUpdate({required dynamic onVideoTimeUpdate(double currentTime)?}) → void
changeVideoTitle({String? customVideoTitle}) → Future<void>
createVideoListeners() → Future<void>
hidenVideoTitle({bool hiden = true}) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onFullScreenStateChanged({required dynamic onVideoStateChange(VideoState state)?}) → Future<void>
removeChannleImage({required bool hidenChannelImage}) → Future<void>
removeMoreOptionsAndShareButtons() → Future<void>
removeYoutubeWatermark() → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited