VideoController class

Constructors

VideoController(InAppWebViewController controller)

Properties

controller → InAppWebViewController
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
videoDuration ↔ double
getter/setter pair

Methods

getAllVideoTime() → Future<void>
GET THE VIDEO DURATION
muteOrUnmuteVideo() → Future<void>
MUTE THE VIDEO
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pauseVideo() → Future<void>
PAUSE THE VIDEO
playVideo() → Future<void>
/ THE VIDEO DURATION PLAY THE VIDEO
seekTo({required double time}) → Future<void>
SEEK TO A SPECIFIC TIME IN THE VIDEO
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited