YoutubePlayerEmbed class

/ YOUTUBE PLAYER VIEW WIDGET

Inheritance

Constructors

YoutubePlayerEmbed({Key? key, required String videoId, dynamic callBackVideoController(VideoController)?, String? customVideoTitle, bool autoPlay = true, bool hidenVideoControls = false, bool mute = false, bool hidenChannelImage = true, double? aspectRatio, bool enabledShareButton = false, VoidCallback? onVideoEnd, dynamic onVideoSeek(double currentTime)?, dynamic onVideoTimeUpdate(double currentTime)?, dynamic onVideoStateChange(VideoState state)?})
/ CONSTRUCTOR

Properties

aspectRatio double?
final
autoPlay bool
final
callBackVideoController → dynamic Function(VideoController)?
final
customVideoTitle String?
final
enabledShareButton bool
final
hashCode int
The hash code for this object.
no setterinherited
hidenChannelImage bool
final
hidenVideoControls bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mute bool
final
onVideoEnd VoidCallback?
final
onVideoSeek → dynamic Function(double currentTime)?
final
onVideoStateChange → dynamic Function(VideoState state)?
final
onVideoTimeUpdate → dynamic Function(double currentTime)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoId String
/ PROPERTIES
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<YoutubePlayerEmbed>
/ CREATE STATE
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited